==> core-0.4.1.tgz: package/lib/net/Server.js <==
var Class = require("../class/Class.js").Class;
var Request = require("./Request.js").Request;
var Response = require("./Response.js").Response;
var BinaryData = require("./../data/BinaryData.js").BinaryData;
var RequestProcessor = require("./RequestProcessor.js").RequestProcessor;
var Crypto = require("../common/Crypto.js");
var http = require('http');


//var PAGE = require('fs').readFileSync('/tmp/EdgeServer/examples/performance/onet.txt');
//httpResponse.writeHead(200, {'content-length':PAGE.length});
//httpResponse.end(PAGE);
//return;

/**
 * @class Server Main http server class. Wraps native node.js http object. Creates Request processor instance and dispatch processing. 
 * @param {Class} RequestProcessorClass Subclass of RequestProcessor family.
 */
var Server = function(){
    this.RequestProcessorClass = null;
    this._server = null;
    this._requestCounter = 0;
    
    this.initialize = function(RequestProcessorClass){
        this.RequestProcessorClass = RequestProcessorClass;
        var that = this;
        
        this._server = http.createServer(function(request, response) {
            that._onRequestHandler(request, response);
        });
    };
    
    this.listen = function(port, host){
        this._server.listen(port, host);
    };
    
    this.listenFD = function(fd, protocol){
        this._server.listenFD(fd, protocol);  
    };
    /**
     * Returns native http server instance.
     * @public
     * @returns http.Server
     */
    this.getClusterNode = function(){
        return this._server;
    };
    /**
     * @private
     */
    this._onRequestHandler = function(httpRequest, httpResponse) {
        
        console.log('\n-- request started');
        
        this._createUniqueRequestId(httpRequest);

        var that = this;
        var postData = [];
        httpRequest.on('end', function() {
        
            // 892 -925
            httpRequest.data = new BinaryData(
                postData.join(""), 
                BinaryData.Encoding.TEXT, 
                BinaryData.CharacterEncoding.UTF8
            );
            
            //888-892
            var request = new Request(httpRequest);    // 824-831 - return w konstruktorze
            
            //703-726
            var response = new Response(httpResponse);
            
            // 695- 713
            var requestProcessor = that.createRequestProcessor();
            requestProcessor.process(request, response);

			var requestLine = '"' + request.getMethod() + ' ' + request.getPath() + ' ' + request.getHttpVersion() + '"';

			var referer = request.getHeader('referer');
			referer = '"' + (referer ? referer : '-') + '"';
			var userAgent = request.getHeader('user-agent');
			userAgent = '"' + (userAgent ? userAgent : '-') + '"';

			var timeStart = +(new Date());

			response.addEventListener(Response.Event.SEND, function(e){
				var responseCode = response.getStatusCode();
				var responseSize = response.getBody().length();

				var requestTime = 'req_time=' + (+(new Date()) - timeStart) + 'ms';

				console.info("access", [requestLine, responseCode, responseSize, referer, userAgent, requestTime].join(" "));
			});
        });
        httpRequest.on('data', function(data) {
            postData.push(data);
        });
    };
    this.getServer = function(){
        return this;
    };
    this.createRequestProcessor = function(){
        var requestProcessor = new this.RequestProcessorClass(this.getServer());
        if(!(requestProcessor instanceof  RequestProcessor)){
            throw Server.Exception.WRONG_PROCESSOR_CLASS;
        }
        return requestProcessor;
    };
    this._createUniqueRequestId = function(httpRequest){
        //generuje request id
        var instanceId = process.env.NS_INSTANCE_ID || "UNKNOWN";

        httpRequest.headers['X-RID'] = ""
            + instanceId
            + "-" + this._requestCounter++
            + "-" + (+ new Date())
            + "-" + (new Buffer(httpRequest.headers.host).toString('base64'))
            
        if(this._requestCounter>=Number.MAX_VALUE){
            this._requestCounter = 0;
        }
    };
}

Server = new Class(new Server());

/**
 * Namespace for exceptions messages.
 * @static
 * @namespace
 */
Server.Exception = {};
/**
 * @static
 * @public
 */
Server.Exception.WRONG_PROCESSOR_CLASS = "Request processor class must be inheriting RequestProcessor";
//

exports.Server = Server;

==> core-0.4.5.tgz: package/lib/net/Server.js <==
var Class = require("../class/Class.js").Class;
var Request = require("./Request.js").Request;
var Response = require("./Response.js").Response;
var BinaryData = require("./../data/BinaryData.js").BinaryData;
var RequestProcessor = require("./RequestProcessor.js").RequestProcessor;
var Crypto = require("../common/Crypto.js");
var Types = require("../common/Types.js");

var http = require('http');



//var PAGE = require('fs').readFileSync('/tmp/EdgeServer/examples/performance/onet.txt');
//httpResponse.writeHead(200, {'content-length':PAGE.length});
//httpResponse.end(PAGE);
//return;

/**
 * @class Server Main http server class. Wraps native node.js http object. Creates Request processor instance and dispatch processing. 
 * @param {Class} RequestProcessorClass Subclass of RequestProcessor family.
 */
var Server = function(){
    this.RequestProcessorClass = null;
    this._server = null;
    this._requestCounter = 0;
    
    this.initialize = function(RequestProcessorClass){
        this.RequestProcessorClass = RequestProcessorClass;
        var that = this;
        
        this._server = http.createServer(function(request, response) {
            that._onRequestHandler(request, response);
        });
    };
    
    this.listen = function(port, host){
        this._server.listen(port, host);
    };
    
    this.listenFD = function(fd, protocol){
        this._server.listenFD(fd, protocol);  
    };
    /**
     * Returns native http server instance.
     * @public
     * @returns http.Server
     */
    this.getClusterNode = function(){
        return this._server;
    };
    /**
     * @private
     */
    this._onRequestHandler = function(httpRequest, httpResponse) {
        
        console.log('\n-- request started');
        
        this._createUniqueRequestId(httpRequest);

        var that = this;

        var dataLength = 0, buffers = [];
        
        // gathering post data
        httpRequest.on('data', function(data) {
            buffers.push(data);
            dataLength += data.length;
        });
        
        // i'm the master of every buffer @ post data'
        httpRequest.on('end', function() {
            
            var joinedBuffer = new Buffer(dataLength), bufferPosition = 0;
            for(var i = 0, l = buffers.length; i < l; i++){
                buffers[i].copy(joinedBuffer, bufferPosition);
                bufferPosition += buffers[i].length;
            }
            
            // 892 -925
            httpRequest.data = new BinaryData(
                joinedBuffer,
                BinaryData.Encoding.BINARY
            );
            
            //888-892
            var request = new Request(httpRequest);    // 824-831 - return w konstruktorze
            
            //703-726
            var response = new Response(httpResponse);
            
            // 695- 713
            var requestProcessor = that.createRequestProcessor();
            requestProcessor.process(request, response);

            // access log line
			var requestLine = '"' + request.getMethod() + ' ' + request.getPath() + ' ' + request.getHttpVersion() + '"';
			var referer = request.getHeader('referer');
			referer = '"' + (referer ? referer : '-') + '"';
			var userAgent = request.getHeader('user-agent');
			userAgent = '"' + (userAgent ? userAgent : '-') + '"';
			var timeStart = +(new Date());
			response.addEventListener(Response.Event.SEND, function(e){
				var responseCode = response.getStatusCode();
                var body = response.getBody();
                var responseSize = null;
                if(Types.isInstanceOf(body, BinaryData)){
                    responseSize = body.length();
                } else {
                    responseSize = body.length;
                }
				var requestTime = 'req_time=' + (+(new Date()) - timeStart) + 'ms';
				console.info("access", [requestLine, responseCode, responseSize, referer, userAgent, requestTime].join(" "));
			});

        });

    };
    this.getServer = function(){
        return this;
    };
    this.createRequestProcessor = function(){
        var requestProcessor = new this.RequestProcessorClass(this.getServer());
        if(!(requestProcessor instanceof  RequestProcessor)){
            throw Server.Exception.WRONG_PROCESSOR_CLASS;
        }
        return requestProcessor;
    };
    this._createUniqueRequestId = function(httpRequest){
        //generuje request id
        var instanceId = process.env.NS_INSTANCE_ID || "UNKNOWN";

        httpRequest.headers['X-RID'] = ""
            + instanceId
            + "-" + this._requestCounter++
            + "-" + (+ new Date())
            + "-" + (new Buffer(httpRequest.headers.host).toString('base64'))
            
        if(this._requestCounter>=Number.MAX_VALUE){
            this._requestCounter = 0;
        }
    };
}

Server = new Class(new Server());

/**
 * Namespace for exceptions messages.
 * @static
 * @namespace
 */
Server.Exception = {};
/**
 * @static
 * @public
 */
Server.Exception.WRONG_PROCESSOR_CLASS = "Request processor class must be inheriting RequestProcessor";
//

exports.Server = Server;
